@@ -1,11 +1,13 @@
+import sys
+
 from cricket.model import Project
 
 class UnittestProject(Project):
 
     def discover_commandline(self):
         "Command line: Discover all available tests in a project."
-        return ['python', '-m', 'cricket.unittest.discoverer']
+        return [sys.executable, '-m', 'cricket.unittest.discoverer']
 
     def execute_commandline(self, labels):
         "Return the command line to execute the specified test labels"
-        return ['python', '-m', 'cricket.unittest.executor'] + labels
\ No newline at end of file
+        return [sys.executable, '-m', 'cricket.unittest.executor'] + labels
\ No newline at end of file
